# nygen-default

nygen's default template

## Usage

`nygen init --author "Natalie Fearnley" --email "nfearnley@gmail.com" --github "nfearnley"`

`cd c:\users\nfear\Desktop\coding`

`nygen myproject --template default`